@@ -1,7 +1,8 @@
 package Reddit::Client;
 
-our $VERSION = '1.2817';
+our $VERSION = '1.29';
 # TODO: make ispost, iscomment and get_type static
+# 1.29  -added is_original_content flag to Link
 # 1.2817-documentation update
 # 1.281 -morecomments get_collapsed args
 # 1.281 -get_collapsed can also return morecomments
@@ -1565,6 +1566,8 @@ __END__
 
 =pod
 
+=pod
+
 =head1 NAME
 
 Reddit::Client - A Perl wrapper for the Reddit API.
@@ -1628,15 +1631,15 @@ Reddit::Client uses Oauth to communicate with Reddit. To get Oauth keys, visit y
 
 =item Script apps
 
-Most users will want a "script"-type app. This is an app intended for personal use that uses a username and password to authenticate. The I<description> and I<about url> fields can be empty, and the I<redirect URI> can be any valid URL (script apps don't use them). Once created, you can give other users permission to use it by adding them in the "add developer" field. (They each use their own username and password to authenticate.)
+Most users will want a "script"-type app. This is an app intended for personal use that uses a username and password to authenticate. The I<description> and I<about url> fields can be empty, and the I<redirect URI> can be any valid URL (script apps don't use them). Once created, you can give other users permission to use it by adding them in the "add developer" field. Each account uses its own username and password to authenticate.
 
 Use the app's client id and secret along with your username and password to create a L<new|https://metacpan.org/pod/Reddit::Client#new> Reddit::Client object.
 
 =item Web apps
 
-As of v1.20, Reddit::Client also supports "web" apps. These are apps that can take actions on behalf of any user that grants them permission. (If you have ever seen a permission screen for a Reddit app that says "SomeRedditApp wants your permission to...", that's a web app.)
+As of v1.20, Reddit::Client also supports "web" apps. These are apps that can take actions on behalf of any user that grants them permission. (This uses the familiar "SomeRedditApp wants your permission to..." screen.)
 
-While they are fully supported, there is not yet a setup guide, so getting one running is left as an exercise for the reader. You will need a web server, which you will use to direct users to Reddit's authorization page, which will get the user's permission to do whatever the app has asked to do. It will then redirect the user back to the app's I<redirect URI>. This process generates a refresh token, which is a unique string that your app will use to authenticate instead of a username and password. You will probably want to store refresh tokens locally, otherwise you will have to get permission from the user every time the app runs.
+While they are fully supported, there is not yet a setup guide, so getting one running is left as an exercise for the reader. You will need a web server, which you will use to direct users to Reddit's authorization page, which will get the user's permission to do whatever the app has asked to do. It will then redirect the user back to the app's redirect URI. This process generates a refresh token, which is a unique string that your app will use to authenticate instead of a username and password. You will probably want to store refresh tokens locally, otherwise you will have to get permission from the user every time the app runs.
 
 Documentation for the web app flow can be found at L<https://github.com/reddit-archive/reddit/wiki/OAuth2>.
 
@@ -1648,14 +1651,14 @@ Reddit's API is slightly inconsistent in its naming. To avoid confusion, this gu
 
 =over
 
-=item fullname
-
-A thing's complete ID with prefix. Example: t1_3npkj4. Whe Reddit returns data, the fullname is usually found in the "name" field. The type of thing can be determined by the prefix; for example, t1 for comments and t3 for links.
-
 =item id
 
 A thing's short ID without prefix. Example: 3npkj4. Seen in your address bar when viewing, for example, a post or comment. 
 
+=item fullname
+
+A thing's complete ID with prefix. Example: t1_3npkj4. When Reddit returns data, the fullname is usually found in the "name" field. The type of thing can be determined by the prefix; for example, t1 for comments and t3 for links.
+
 =back
 
 =head1 LISTINGS
@@ -1682,7 +1685,7 @@ Note that 'before' and 'after' mean before and after I<in the listing>, not nece
 
 =head1 MISC
 
-All functions that take the parameter 'subreddit' also accept the alias 'sub'.
+All functions that take the parameter C<subreddit> also accept the alias C<sub>.
 
 This guide indicates optional arguments with brackets ([]), a convention we borrowed from from PHP's online manual. This creates some slight overlap with Perl's brackets, which are used to indicate an anonymous array reference, however which of the two is intended should be clear from the context.
 
@@ -1707,9 +1710,9 @@ Ban a user from a subreddit. C<username> and C<subreddit> are required. Optional
 
 C<duration>: Duration in days. Range 1-999. If false or not provided, the ban is indefinite.
 
-C<ban_message>: The message sent to the banned user. (Markdown is allowed.)
+C<ban_message>: The message sent to the banned user. Markdown is allowed.
 
-C<reason>: A short ban reason (100 characters max). On the website ban page, this matches the ban reason you would select from the dropdown menu. It is arbitrary: it doesn't have to match up with the reasons from the menu and can be blank. Only visible to moderators.
+C<reason>: A short ban reason, 100 characters max. On the website ban page, this matches the ban reason you would select from the dropdown menu. It is arbitrary: it doesn't have to match up with the reasons from the menu and can be blank. Only visible to moderators.
 
 C<note>: An optional note, 300 characters max. Only visible to moderators. Will be concatenated to the `reason` on the subreddit's ban page.
 
@@ -1781,7 +1784,7 @@ Edit a text post or comment. Unlike on the website, C<$text> can be an empty str
 
 =item edit_multi
 
-Edit a multireddit. Will create a new multireddit if one with that name doesn't exist. The arguments are identical to [create_multi](#create_multi).
+Edit a multireddit. Will create a new multireddit if one with that name doesn't exist. The arguments are identical to L<create_multi|https://metacpan.org/pod/Reddit::Client#create_multi>.	
 
 =item edit_wiki
 
@@ -1798,6 +1801,8 @@ C<reason> is the edit reason. Max 256 characters, will be truncated if longer. O
 
 C<previous> is the ID of the intended previous version of the page; if provided, that is the version the page will be rolled back to in a rollback. However, there's no way to find out what this should be from the Reddit website, or currently from Reddit::Client either. Use it only if you know what you're doing.
 
+Note that if you are updating your sub's automod (which you can do using the page "config/automoderator"), and it has syntax errors, it will fail with the message "HTTP 415 Unsupported Media Type".
+
 =back
 
 =item find_subreddits
