@@ -6,10 +6,14 @@ use Carp;
 
 use List::Util qw/first/;
 
-our @BOOL_FIELDS = qw/is_self likes clicked saved hidden over_18 over18 edited
-                      has_mail has_mod_mail is_mod is_gold was_comment new
-		      public_traffic is_employee verified has_verified_email/;
-
+# If a field is used by another class it must also be added to that class's 
+# fields
+our @BOOL_FIELDS = qw/
+	is_self likes clicked saved hidden over_18 over18 edited
+    has_mail has_mod_mail is_mod is_gold was_comment new
+    public_traffic is_employee verified has_verified_email
+	is_original_content
+/;
 
 use fields qw/session name id/;
 
